import 'dart:math';
import 'package:flutter/material.dart';

class AnimatedValidateOverlay extends StatefulWidget {
  final double circleSize;
  final double iconSize;
  final Color backgroundColor;
  final bool dismissOverlayAutomaticallyAfterAnimation;
  final int animationDurationInSeconds;
  AnimatedValidateOverlay({
    this.circleSize = 100,
    this.backgroundColor = Colors.orange,
    this.iconSize = 80,
    this.dismissOverlayAutomaticallyAfterAnimation = true,
    this.animationDurationInSeconds = 2,
  });

  @override
  State createState() => new AnimatedValidateOverlayState();
}

class AnimatedValidateOverlayState extends State<AnimatedValidateOverlay> with SingleTickerProviderStateMixin {

  late Animation<double> _iconAnimation;
  late AnimationController _iconAnimationController;

  @override
  void initState() {
    super.initState();
    _iconAnimationController = new AnimationController(duration: new Duration(seconds: widget.animationDurationInSeconds), vsync: this);
    _iconAnimation = new CurvedAnimation(parent: _iconAnimationController, curve: Curves.elasticOut);
    _iconAnimation.addListener(() => this.setState(() {
      if (_iconAnimationController.isCompleted && widget.dismissOverlayAutomaticallyAfterAnimation) {
        Navigator.pop(context);
      }
    }));
    _iconAnimationController.forward();
  }

  @override
  void dispose() {
    _iconAnimationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Center(
        child: Container(
          width: widget.circleSize,
          height: widget.circleSize,
          decoration: new BoxDecoration(
              color: widget.backgroundColor,
              shape: BoxShape.circle,
          ),
          child: new Transform.rotate(
            angle: _iconAnimation.value * 2 * pi,
            child: new Icon(Icons.done, size: _iconAnimation.value * widget.iconSize,),
          ),
        ),
      ),
    );
  }
}